#
# spec file for package apache2-mod_mpm_itk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname mod_mpm_itk
%define patchlevel 04

Name:           apache2-%{modname}
Version:        2.4.7
Release:        lp150.9.8
Summary:        The Apache 2 ITK MPM
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            http://mpm-itk.sesse.net/
Source:         http://mpm-itk.sesse.net/mpm-itk-%{version}-%{patchlevel}.tar.gz
Source1:        README.SUSE
Source2:        %{modname}.http
BuildRequires:  apache-rpm-macros >= 20160120
BuildRequires:  apache2-devel
BuildRequires:  curl
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2-prefork
%if 0%{?suse_version} > 1320
# for %check
Requires(pre):  user(nobody)
Requires(pre):  group(nobody)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Apache2-mpm-itk (just mpm-itk for short) is a MPM for the Apache 2 web server.
mpm-itk allows you to run each of your vhosts under a separate uid and gid --
in short, the scripts and configuration files for one vhost no longer have to
be readable for all the other vhosts.

%prep
%setup -q -n mpm-itk-%{version}-%{patchlevel}
cp %{SOURCE1} .

%build
%configure --with-apxs=%{apache_apxs}
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_libdir}/apache2-prefork
install -m 755 .libs/mpm_itk.so %{buildroot}%{_libdir}/apache2-prefork/mod_mpm_itk.so
install -D -m0644 %{SOURCE2} %{buildroot}%{apache_sysconfdir}/conf.d/%{modname}.conf

%check
# this check will really work only when run as root, for example
# with osc build --build-uid=0:0; for abuild:abuild, it can be tested
# for error_log output, at least
as_root=0
if [ $(id -u) -eq 0 ]; then
  as_root=1
else
  # remove old error_log as we will test it later
  rm -f %{apache_test_module_dir}/error_log
fi
set +x
mkdir -p %{apache_test_module_dir}
mkdir -p %{apache_test_module_dir}/test-htdocs
# create test configuration of virtual host
cat << EOF > %{apache_test_module_dir}/mpm_itk-test.conf
<VirtualHost *>
  ServerName test
  DocumentRoot %{apache_test_module_dir}/test-htdocs
  ErrorLog %{apache_test_module_dir}/test-error_log
  # this is actually tested -- changing uid and gid for
  # request handling
  AssignUserID nobody nogroup
  # tested on simple cgi scripts; these return id -nu and id -ng
  ScriptAlias /test-cgi-bin/ "%{apache_test_module_dir}/test-cgi-bin/"
  <Directory "%{apache_test_module_dir}/test-cgi-bin">
    Options +ExecCGI
    Require local
  </Directory>
</VirtualHost>
EOF
# creating script which returns id -nu
mkdir -p %{apache_test_module_dir}/test-cgi-bin/
cat << EOF > %{apache_test_module_dir}/test-cgi-bin/user.sh
#!/bin/sh
echo "Content-type: text/html"
echo ""
id -nu
EOF
# creating script that return is -ng
cat << EOF > %{apache_test_module_dir}/test-cgi-bin/group.sh
#!/bin/sh
echo "Content-type: text/html"
echo ""
id -ng
EOF
chmod +x %{apache_test_module_dir}/test-cgi-bin/*.sh
exit_code=0
# start apache instance
%apache_test_module_start_apache -m alias:cgi:mpm_itk -i mpm_itk-test.conf -u wwwrun -g www
# curl user.sh and group.sh to gather uid and gid of the request
# handler
echo
echo 'Testing test-cgi-bin/user.sh and test-cgi-bin/group.sh output'
%apache_test_module_curl -d test-cgi-bin/user.sh -o %{apache_test_module_dir}/user.txt
%apache_test_module_curl -d test-cgi-bin/group.sh -o %{apache_test_module_dir}/group.txt
# this check will really work only when run as root, for example
# with osc build --build-uid=0:0; for abuild:abuild, it can be tested
# for error_log output, at least
if [ $as_root -eq 1 ]; then
  grep nobody %{apache_test_module_dir}/user.txt || exit_code=1
  grep nogroup %{apache_test_module_dir}/group.txt || exit_code=1
else
  # mpm_itk fails to change user, because httpd is running under abuild:abuild
  grep 'itkmpm:.*setgid.*Operation not permitted' %{apache_test_module_dir}/error_log || exit_code=1
fi
if [ $exit_code -eq 0 ]; then
  echo 'SUCCESS'
else
  echo 'FAILED'
fi
echo
%apache_test_module_stop_apache
set -x
exit $exit_code

%files
%defattr(-,root,root)
%doc CHANGES README README.SUSE
%config(noreplace) %{apache_sysconfdir}/conf.d/%{modname}.conf
%{_libdir}/apache2-prefork/mod_mpm_itk.so

%changelog
* Mon Feb 12 2018 chris@computersalat.de
- add mod_mpm_itk.http
  prevents alerts in error_log
- fix deps for apache-rpm-macros
* Fri May 19 2017 pgajdos@suse.com
- updated to 2.4.7-04
  - Add a new flag EnableCapabilities (default on), which can be disabled
    to revert to the behavior in place before 2.4.2-02, which causes problems
    when the filesystem in use does not respect capabilities (in particular
    NFS).
  - Fix an issue where connections would be attempted closed in the parent
    instead of in the child. This would result in "Connection: close" not being
    honored, and various odd effects with SSL keepalive in certain browsers.
  - Correct a log message on AssignGroupIDExpr failure; patch from Roland Mas.
* Tue Jan 12 2016 pgajdos@suse.com
- %%check: access syntax of apache 2.4 branch, module is not
  available for 2.2
* Wed Sep 23 2015 pgajdos@suse.com
- test package with %%apache_test_module_curl
* Mon Sep 21 2015 pgajdos@suse.com
- install module as %%{_libdir}/apache2-prefork/mod_mpm_itk.so instead
  of                %%{_libdir}/apache2-prefork/mpm_itk.so
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- buildrequire apache-rpm-macros
* Thu Oct 30 2014 pgajdos@suse.com
- use apache rpm macros
- add README.SUSE
* Fri Oct 17 2014 pgajdos@suse.com
- Apache-2.0 license
* Wed Oct 15 2014 pgajdos@suse.com
- initial package based on home:nixda:apache24-php/mpm-itk
  (there was not *.changes file) [bnc#851229]
